API docs for “spamfighter.core.commands.errors”

# Module s.c.c.errors

Part of spamfighter.core.commands View Source

Базовые классы обработки ошибок при выполнении команд.

Class | BaseCommandException | Базовое исключение при обработке команды
Class | InternalCommandException | Сообщение о внутренней ошибке сервера.
Class | FatalCommandException | Фатальная ошибка, приводящая к закрытию текущего соединения.
Class | UnexpectedException | Исключение об неизвестной ситуации при обработке команды
Class | CommandResultMissingException | Исключение об отсутствии результата команды
Class | CommandParamsMissingException | Исключение об отсутствии параметров команды
Class | CommandUnknownException | Исключение о неизвестной команде.
Class | UnknownParameterException | Исключение о передаче неизвестного параметра для команды.
Class | TypeParameterException | Исключение о передаче параметра неверного типа.
Class | AuthorizationFailedException | Авторизация через партнера не удалась.
Class | DomainPathNotFoundException | Указанный путь к домену не валиден.
Class | AttributeKeyException | Атрибут не найден в домене.
Class | SkipToFallthroughError | В firewall не нашлось метки для skip to...
Class | NotAModelError | Указанный объект не является моделью.
Class | MessageAttributeKeyException | Атрибут не найден в сообщении.
Class | NotAFirewallError | Указанный объект не является firewallом.
Class | FirewallSyntaxError | Ошибка синтаксиса правил firewall.
Class | NotAMessageLogError | Указанный объект не является логом сообщений.